####################################################################
####################################################################
## Paper:  NHST negative results Article                          ##
##                                                                ##
## Authors: Farrat et al.                                         ##
##                                                                ##
## Code Author: BF                                                ##  
##                                                                ##
## Version: Pre-print                                             ##
##                                                                ##
## Software: R 4.0.2                                              ##
##                                                                ##
## Purpose: Produce summary statistics and visualisation          ##
####################################################################
####################################################################

rm(list = ls())

##################################################
## Load packages, install packages if necessary ##
##################################################

package.list <- c("tidyverse", "extrafont", "readxl", "RcmdrMisc")
new.packages <- package.list[!(package.list %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)
lapply(package.list, library, character.only = TRUE)

## NB, if this is your first time running extraFont, the following  line is required to 
## load the fonts (run time ~ 3 mins). You might need to restart R following running the code, too. 

#font_import()
#loadfonts()

textsize <- 20 ## Set size of axis labels

#####################
## Data Directory ###
#####################

data_directory <- "3_Data/"

#######################
## Output Directory ###
#######################

r <- "~/5_Results/"

######################
## Data Directory ####
######################
data <- read_excel(paste(data_directory, "QCcomplete/QC_BFDecisions_and_Extractions_Ambiguous_Recoded.xlsx", sep = ""), 1, skip = 2)


################################################
## Exclude those without NHST, drop columns ####
################################################

d <- data
d <- d %>% filter(is.na(INCLUDE)) %>% filter(NHST != "No" & NHST != "No, not in relation to the negative claim" & NHST != "?")

cols <- c("JOURNAL", "YEAR", "ISSUE", "AUTHORS", "NHST", "TITLE", "TTLAGREE", "TTLDECISION", "TLTNOEFF",
                 "TTLFRAME", "ABSSTEXT", "ABSSAGREE", "ABSSDECISION", "ABSSFRAME", "ABSPTEXT", "ABSPAGREE", "ABSPDECISION",
                 "ABSPFRAME", "RESULT", "RESULTAGREE", "RESTEXTDEC", "RESDEC", "RESPVAL")

clean <- d[, names(d) %in% cols]

##################
#### Analysis ####
##################

## N articles
nrow(clean)

## N articles by jounral
clean %>% group_by(JOURNAL) %>% count

######################
#### QC Agreement ####
######################

clean %>% count(TTLAGREE)
clean %>% count(ABSSAGREE)
clean %>% count(ABSPAGREE)
clean %>% count(RESULTAGREE)

################
#### Titles ####
################
clean %>% count(TTLDECISION)
clean %>% count(TLTNOEFF)
clean %>% group_by(TLTNOEFF) %>% count(TTLDECISION)

#########################
#### Abstract Sample ####
#########################
clean %>% count(ABSSDECISION)
clean %>% count(ABSSFRAME)

#########################
#### Abstract Population ####
#########################
clean %>% count(ABSPDECISION)
clean %>% count(ABSPFRAME) %>% print(n=40)

################
#### Result ####
################
clean %>% count(RESDEC)


### Predict abstract sample from results sample
absres <- clean %>% filter(ABSSDECISION == "Correct" | ABSSDECISION == "No Effect") %>% 
  filter(RESDEC == "Correct" | RESDEC == "No Effect")

a <- absres %>% group_by(ABSSDECISION) %>% count(RESDEC)
b <- xtabs(n ~ ABSSDECISION + RESDEC, data = a)
chisq.test(b)

##############
## p-values ##
##############

clean$RESPVAL <- as.numeric(clean$RESPVAL)
pvaluesall <- clean %>% filter(between(RESPVAL, 0, 1.01))
pvalues <- clean %>% filter(between(RESPVAL, 0.049999, 1.01))

#number below 0.05
nrow(pvaluesall) - nrow(pvalues)

pvalues %>% ggplot(aes(x = RESPVAL)) + 
  geom_histogram(aes(y=..density..), binwidth = 0.02, colour="black", fill="white") +
  geom_hline(yintercept = 1, colour = 'black', linetype = "dotted", size = 2) +
  geom_density(alpha=.2, fill="#FF6666") + 
  xlab("Non-significant p value") + scale_x_continuous(breaks = c(0.05, 0.25, 0.50, 0.75, 1.0), labels = c(0.05, 0.25, 0.50, 0.75, 1.0)) + ylab ("Density") + theme_classic() + 
  theme(text=element_text(family="Tahoma", size=16))

ks.test(pvalues$RESPVAL, "punif", 0.05, 1, alternative = "two.sided")

#################
## simulations ##
#################

##W caclulate effect size for 33%, 50% and 80% power
power.t.test(10, delta = NULL, 5, power = 0.10, sig.level=0.05, type="two.sample", alternative = "two.sided")
power.t.test(10, delta = NULL, 5, power = 0.33, sig.level=0.05, type="two.sample", alternative = "two.sided")
power.t.test(10, delta = NULL, 5, power = 0.50, sig.level=0.05, type="two.sample", alternative = "two.sided")
power.t.test(10, delta = NULL, 5, power = 0.80, sig.level=0.05, type="two.sample", alternative = "two.sided")
delta10 <- 1.600722
delta33 <- 3.58967
delta50 <- 4.630629
delta80 <- 6.624728

Nsim <- 10000
# proportion H1 correct
H1c <- 0.8
## Run 10,000 simulations for each power
set.seed(222)
##33
p10 <- NULL

for(i in 1:Nsim*H1c){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000-delta10, 5)
  
  p10[i] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

for(i in 1:Nsim*(1-H1c)){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000, 5)
  
  p10[i+800] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

## proportion significant
sum(p10<0.05)/100000

sim10 <- data.frame(journal = "10% Power Simulation", "pvalue" = p10)

##33
p33 <- NULL

for(i in 1:Nsim*H1c){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000-delta33, 5)
  
  p33[i] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

for(i in 1:Nsim*(1-H1c)){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000, 5)
  
  p33[i+800] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

## proportion significant
sum(p33<0.05)/1000000

sim33 <- data.frame(journal = "33% Power Simulation", "pvalue" = p33)

##50
p50 <- NULL

for(i in 1:Nsim*H1c){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000-delta50, 5)
  
  p50[i] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

for(i in 1:Nsim*(1-H1c)){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000, 5)
  
  p50[i+800] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

## proportion significant
sum(p50<0.05)/1000000

sim50 <- data.frame(journal = "50% Power Simulation", "pvalue" = p50)

##80
p80 <- NULL

for(i in 1:Nsim*H1c){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000-delta80, 5)
  
  p80[i] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

for(i in 1:Nsim*(1-H1c)){
  sample1 <- rnorm(10, 1000, 5)
  
  sample2 <- rnorm(10, 1000, 5)
  
  p80[i+800] <- t.test(sample1, sample2, alternative = "two.sided")$p.value
}

## proportion significant
sum(p80<0.05)/1000000

sim80 <- data.frame(journal = "80% Power Simulation", "pvalue" = p80)

##################################################
## join simulation to original dataset and plot ##
##################################################

short <- pvalues[c("JOURNAL", "RESPVAL")]
names(short)[c(1, 2)] <- c("journal", "pvalue")
short$journal <- "Literature"
comparison <- rbind(short, sim10, sim33, sim50, sim80) %>% filter(pvalue > 0.05)

comparison %>% ggplot(aes(x = pvalue)) + facet_grid(.~ journal) +
  geom_histogram(aes(y=..density..), binwidth = 0.075, colour="black", fill="white") +
  xlab("Non-significant p value") + 
  scale_x_continuous(breaks = c(0.05, 0.25, 0.50, 0.75, 1.0), labels = c(0.05, 0.25, 0.50, 0.75, 1.0)) + 
  ylab ("Density") + theme_classic() + 
  theme(text=element_text(family="Tahoma", size=16),
        strip.background = element_blank())

pvalues$RESPVAL > 0.05

sim10ns <- filter(sim10, pvalue > 0.05)
sim33ns <- filter(sim33, pvalue > 0.05)
sim50ns <- filter(sim50, pvalue > 0.05)
sim80ns <- filter(sim80, pvalue > 0.05)

a <- hist(pvaluesns$RESPVAL, plot = FALSE, breaks = 20)$counts
b <- hist(sim10ns$pvalue, plot = FALSE, breaks = 20)$counts
c <- hist(sim33ns$pvalue, plot = FALSE, breaks = 20)$counts
d <- hist(sim50ns$pvalue, plot = FALSE, breaks = 20)$counts
e <- hist(sim80ns$pvalue, plot = FALSE, breaks = 20)$counts

hist(sim80$pvalue, plot = FALSE, breaks = 20)
manualcomparison <- as.data.frame(cbind(a, a/nrow(pvalues), b, b/nrow(sim10ns), c, c/nrow(sim33ns), d, d/nrow(sim50ns), e, e/nrow(sim80ns)))
write.csv(manualcomparison, "manualcomparison.csv")


#pvalues$RESDEC <- as.factor(pvalues$RESDEC)
#pvalues$ABSSDECISION <- as.factor(pvalues$ABSSDECISION)

#pval <- pvalues %>% filter(RESDEC == "No Effect" | RESDEC == "Correct") %>% 
#  filter(ABSSDECISION == "No Effect" | ABSSDECISION == "Correct")


#pval %>% ggplot(aes(x = RESPVAL)) + 
#  geom_histogram(binwidth = 0.02, colour="black", fill="white") +
#  geom_hline(yintercept = 1, colour = 'black', linetype = "dotted", size = 2) +
#  geom_density(alpha=.2, fill="#FF6666") + 
#  facet_grid(ABSSDECISION~RESDEC, labeller = label_both) +
#  xlab("Non-significant p value") + scale_x_continuous(breaks = c(0.05, 0.25, 0.50, 0.75, 1.0), labels = c(0.05, 0.25, 0.50, 0.75, 1.0)) + ylab ("Count") + theme_classic() + 
#  theme(text=element_text(family="Tahoma", size=16), 
#        strip.background = element_blank())


